@@ -183,3 +183,62 @@ warnings <- function(formula,     #formula: assume treatment is 1st term on rhs
 }            
 
 
+#################
+#warnings for BART SA
+#################
+
+warningsBART <- function(formula,     #formula: assume treatment is 1st term on rhs
+                         grid.dim,    #final dimensions of output grid
+                         verbose,
+                         zetay.range,  	#custom range for zeta^y, e.g.(0,10), zero.loc will be overridden.
+                         zetaz.range,  	#custom range for zeta^z, e.g.(-2,2), zero.loc will be overridden.
+                         weights,     #some user-specified vector or "ATE", "ATT", or "ATC" for GLM.sens to create weights.
+                         data) {
+  
+  if(is.null(data)) stop(paste("Either a matrix or data.frame object must be specified in data field."))
+  
+  #check that data is a data frame
+  if(identical(class(data),"matrix")) {
+    if(verbose) warning("coerced matrix to data frame")
+    data = data.frame(data)
+  }
+  else if(!identical(class(data),"data.frame")) {
+    stop(paste("Data is not a data.frame object"))
+  } 
+  
+  #Code for listwise deletion
+  postdata=na.omit(data)
+  nobs.deleted = dim(data)[1] - dim(postdata)[1]
+  if ((verbose) & nobs.deleted>0) warning(nobs.deleted, " observations were deleted listwise.\n") 
+  
+  #extract variables from formula
+  form.vars <- parse.formula(formula, data)
+  Y = form.vars$resp
+  Z = form.vars$trt
+  X = form.vars$covars 
+  
+  #check whether the dimentions of grid are at least 2.
+  if(!is.null(grid.dim) && (length(grid.dim) != 2)) {
+    stop(paste("Error: grid dimenstions must a vector of length 2"))
+  }
+  
+  #If single value entered for range with 1 cell grid, expand to length 2 to avoid errors
+  if(!is.null(zetay.range) && length(zetay.range) == 1 && (grid.dim == 1 | all.equal(grid.dim, c(1,1)))) 
+    zetay.range = c(zetay.range, zetay.range)
+  if(!is.null(zetaz.range) && length(zetaz.range) == 1 && (grid.dim == 1 | all.equal(grid.dim, c(1,1)))) 
+    zetaz.range = c(zetaz.range, zetaz.range)
+  
+  #If single value entered for range with >1 cell grid, return an error
+  if(!is.null(zetay.range) && (length(zetay.range) != 2)) {
+    stop(paste("Error: zeta.y range must a vector of length 2"))
+  }
+  if(!is.null(zetaz.range) && (length(zetaz.range) != 2)) {
+    stop(paste("Error: zeta.z range must a vector of length 2"))
+  }
+  
+  return(list(formula=formula,
+              grid.dim=grid.dim,
+              zetay.range=zetay.range,
+              zetaz.range=zetaz.range,
+              data=postdata))
+}            
